@charset "UTF-8";
.form-control,
.dataTables_wrapper .dataTables_length select,
.dataTables_wrapper .dataTables_filter input {
    display: block;
    width: 100%;
    height: 2.375rem;
    padding: 0.375rem 0.75rem;
    font-size: 0.9375rem;
    font-weight: 400;
    line-height: 1.6;
    color: #495057;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid rgba(0, 40, 100, 0.12);
    border-radius: 3px;
    transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
}

@media (prefers-reduced-motion: reduce) {
    .form-control,
    .dataTables_wrapper .dataTables_length select,
    .dataTables_wrapper .dataTables_filter input {
        transition: none;
    }
}

.form-control::-ms-expand,
.dataTables_wrapper .dataTables_length select::-ms-expand,
.dataTables_wrapper .dataTables_filter input::-ms-expand {
    background-color: transparent;
    border: 0;
}

.form-control:focus,
.dataTables_wrapper .dataTables_length select:focus,
.dataTables_wrapper .dataTables_filter input:focus {
    color: #495057;
    background-color: #fff;
    border-color: #1991eb;
    outline: 0;
    box-shadow: 0 0 0 2px rgba(70, 127, 207, 0.25);
}

.form-control::-webkit-input-placeholder,
.dataTables_wrapper .dataTables_length select::-webkit-input-placeholder,
.dataTables_wrapper .dataTables_filter input::-webkit-input-placeholder {
    color: #adb5bd;
    opacity: 1;
}

.form-control::-moz-placeholder,
.dataTables_wrapper .dataTables_length select::-moz-placeholder,
.dataTables_wrapper .dataTables_filter input::-moz-placeholder {
    color: #adb5bd;
    opacity: 1;
}

.form-control::-ms-input-placeholder,
.dataTables_wrapper .dataTables_length select::-ms-input-placeholder,
.dataTables_wrapper .dataTables_filter input::-ms-input-placeholder {
    color: #adb5bd;
    opacity: 1;
}

.form-control::placeholder,
.dataTables_wrapper .dataTables_length select::placeholder,
.dataTables_wrapper .dataTables_filter input::placeholder {
    color: #adb5bd;
    opacity: 1;
}

.form-control:disabled,
.dataTables_wrapper .dataTables_length select:disabled,
.dataTables_wrapper .dataTables_filter input:disabled,
.form-control[readonly],
.dataTables_wrapper .dataTables_length select[readonly],
.dataTables_wrapper .dataTables_filter input[readonly] {
    background-color: #f8f9fa;
    opacity: 1;
}

select.form-control:focus::-ms-value,
.dataTables_wrapper .dataTables_length select:focus::-ms-value {
    color: #495057;
    background-color: #fff;
}

select.form-control[size],
.dataTables_wrapper .dataTables_length select[size],
select.form-control[multiple],
.dataTables_wrapper .dataTables_length select[multiple] {
    height: auto;
}

.was-validated .form-control:valid,
.was-validated .dataTables_wrapper .dataTables_length select:valid,
.dataTables_wrapper .dataTables_length .was-validated select:valid,
.was-validated .dataTables_wrapper .dataTables_filter input:valid,
.dataTables_wrapper .dataTables_filter .was-validated input:valid,
.form-control.is-valid,
.dataTables_wrapper .dataTables_length select.is-valid,
.dataTables_wrapper .dataTables_filter input.is-valid {
    border-color: #5eba00;
    padding-right: calc(1.6em + 0.75rem);
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3e%3cpath fill='%235eba00' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3e%3c/svg%3e");
    background-repeat: no-repeat;
    background-position: center right calc(0.4em + 0.1875rem);
    background-size: calc(0.8em + 0.375rem) calc(0.8em + 0.375rem);
}

.was-validated .form-control:valid:focus,
.was-validated .dataTables_wrapper .dataTables_length select:valid:focus,
.dataTables_wrapper .dataTables_length .was-validated select:valid:focus,
.was-validated .dataTables_wrapper .dataTables_filter input:valid:focus,
.dataTables_wrapper .dataTables_filter .was-validated input:valid:focus,
.form-control.is-valid:focus,
.dataTables_wrapper .dataTables_length select.is-valid:focus,
.dataTables_wrapper .dataTables_filter input.is-valid:focus {
    border-color: #5eba00;
    box-shadow: 0 0 0 2px rgba(94, 186, 0, 0.25);
}

.was-validated .form-control:valid~.valid-feedback,
.was-validated .dataTables_wrapper .dataTables_length select:valid~.valid-feedback,
.dataTables_wrapper .dataTables_length .was-validated select:valid~.valid-feedback,
.was-validated .dataTables_wrapper .dataTables_filter input:valid~.valid-feedback,
.dataTables_wrapper .dataTables_filter .was-validated input:valid~.valid-feedback,
.was-validated .form-control:valid~.valid-tooltip,
.was-validated .dataTables_wrapper .dataTables_length select:valid~.valid-tooltip,
.dataTables_wrapper .dataTables_length .was-validated select:valid~.valid-tooltip,
.was-validated .dataTables_wrapper .dataTables_filter input:valid~.valid-tooltip,
.dataTables_wrapper .dataTables_filter .was-validated input:valid~.valid-tooltip,
.form-control.is-valid~.valid-feedback,
.dataTables_wrapper .dataTables_length select.is-valid~.valid-feedback,
.dataTables_wrapper .dataTables_filter input.is-valid~.valid-feedback,
.form-control.is-valid~.valid-tooltip,
.dataTables_wrapper .dataTables_length select.is-valid~.valid-tooltip,
.dataTables_wrapper .dataTables_filter input.is-valid~.valid-tooltip {
    display: block;
}

.was-validated .custom-select:valid,
.was-validated .dataTables_wrapper .dataTables_length select:valid,
.dataTables_wrapper .dataTables_length .was-validated select:valid,
.custom-select.is-valid,
.dataTables_wrapper .dataTables_length select.is-valid {
    border-color: #5eba00;
    padding-right: calc((1em + 1rem) * 3 / 4 + 1.75rem);
    background: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 10 5'%3E%3Cpath fill='#999' d='M0 0L10 0L5 5L0 0'/%3E%3C/svg%3E") no-repeat right 0.75rem center/8px 10px, url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3e%3cpath fill='%235eba00' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3e%3c/svg%3e") #fff no-repeat center right 1.75rem/calc(0.8em + 0.375rem) calc(0.8em + 0.375rem);
}

.was-validated .custom-select:valid:focus,
.was-validated .dataTables_wrapper .dataTables_length select:valid:focus,
.dataTables_wrapper .dataTables_length .was-validated select:valid:focus,
.custom-select.is-valid:focus,
.dataTables_wrapper .dataTables_length select.is-valid:focus {
    border-color: #5eba00;
    box-shadow: 0 0 0 2px rgba(94, 186, 0, 0.25);
}

.was-validated .custom-select:valid~.valid-feedback,
.was-validated .dataTables_wrapper .dataTables_length select:valid~.valid-feedback,
.dataTables_wrapper .dataTables_length .was-validated select:valid~.valid-feedback,
.was-validated .custom-select:valid~.valid-tooltip,
.was-validated .dataTables_wrapper .dataTables_length select:valid~.valid-tooltip,
.dataTables_wrapper .dataTables_length .was-validated select:valid~.valid-tooltip,
.custom-select.is-valid~.valid-feedback,
.dataTables_wrapper .dataTables_length select.is-valid~.valid-feedback,
.custom-select.is-valid~.valid-tooltip,
.dataTables_wrapper .dataTables_length select.is-valid~.valid-tooltip {
    display: block;
}

.was-validated .form-control:invalid,
.was-validated .dataTables_wrapper .dataTables_length select:invalid,
.dataTables_wrapper .dataTables_length .was-validated select:invalid,
.was-validated .dataTables_wrapper .dataTables_filter input:invalid,
.dataTables_wrapper .dataTables_filter .was-validated input:invalid,
.form-control.is-invalid,
.dataTables_wrapper .dataTables_length select.is-invalid,
.dataTables_wrapper .dataTables_filter input.is-invalid {
    border-color: #cd201f;
    padding-right: calc(1.6em + 0.75rem);
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='%23cd201f' viewBox='-2 -2 7 7'%3e%3cpath stroke='%23cd201f' d='M0 0l3 3m0-3L0 3'/%3e%3ccircle r='.5'/%3e%3ccircle cx='3' r='.5'/%3e%3ccircle cy='3' r='.5'/%3e%3ccircle cx='3' cy='3' r='.5'/%3e%3c/svg%3E");
    background-repeat: no-repeat;
    background-position: center right calc(0.4em + 0.1875rem);
    background-size: calc(0.8em + 0.375rem) calc(0.8em + 0.375rem);
}

.was-validated .form-control:invalid:focus,
.was-validated .dataTables_wrapper .dataTables_length select:invalid:focus,
.dataTables_wrapper .dataTables_length .was-validated select:invalid:focus,
.was-validated .dataTables_wrapper .dataTables_filter input:invalid:focus,
.dataTables_wrapper .dataTables_filter .was-validated input:invalid:focus,
.form-control.is-invalid:focus,
.dataTables_wrapper .dataTables_length select.is-invalid:focus,
.dataTables_wrapper .dataTables_filter input.is-invalid:focus {
    border-color: #cd201f;
    box-shadow: 0 0 0 2px rgba(205, 32, 31, 0.25);
}

.was-validated .form-control:invalid~.invalid-feedback,
.was-validated .dataTables_wrapper .dataTables_length select:invalid~.invalid-feedback,
.dataTables_wrapper .dataTables_length .was-validated select:invalid~.invalid-feedback,
.was-validated .dataTables_wrapper .dataTables_filter input:invalid~.invalid-feedback,
.dataTables_wrapper .dataTables_filter .was-validated input:invalid~.invalid-feedback,
.was-validated .form-control:invalid~.invalid-tooltip,
.was-validated .dataTables_wrapper .dataTables_length select:invalid~.invalid-tooltip,
.dataTables_wrapper .dataTables_length .was-validated select:invalid~.invalid-tooltip,
.was-validated .dataTables_wrapper .dataTables_filter input:invalid~.invalid-tooltip,
.dataTables_wrapper .dataTables_filter .was-validated input:invalid~.invalid-tooltip,
.form-control.is-invalid~.invalid-feedback,
.dataTables_wrapper .dataTables_length select.is-invalid~.invalid-feedback,
.dataTables_wrapper .dataTables_filter input.is-invalid~.invalid-feedback,
.form-control.is-invalid~.invalid-tooltip,
.dataTables_wrapper .dataTables_length select.is-invalid~.invalid-tooltip,
.dataTables_wrapper .dataTables_filter input.is-invalid~.invalid-tooltip {
    display: block;
}

.was-validated .custom-select:invalid,
.was-validated .dataTables_wrapper .dataTables_length select:invalid,
.dataTables_wrapper .dataTables_length .was-validated select:invalid,
.custom-select.is-invalid,
.dataTables_wrapper .dataTables_length select.is-invalid {
    border-color: #cd201f;
    padding-right: calc((1em + 1rem) * 3 / 4 + 1.75rem);
    background: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 10 5'%3E%3Cpath fill='#999' d='M0 0L10 0L5 5L0 0'/%3E%3C/svg%3E") no-repeat right 0.75rem center/8px 10px, url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='%23cd201f' viewBox='-2 -2 7 7'%3e%3cpath stroke='%23cd201f' d='M0 0l3 3m0-3L0 3'/%3e%3ccircle r='.5'/%3e%3ccircle cx='3' r='.5'/%3e%3ccircle cy='3' r='.5'/%3e%3ccircle cx='3' cy='3' r='.5'/%3e%3c/svg%3E") #fff no-repeat center right 1.75rem/calc(0.8em + 0.375rem) calc(0.8em + 0.375rem);
}

.was-validated .custom-select:invalid:focus,
.was-validated .dataTables_wrapper .dataTables_length select:invalid:focus,
.dataTables_wrapper .dataTables_length .was-validated select:invalid:focus,
.custom-select.is-invalid:focus,
.dataTables_wrapper .dataTables_length select.is-invalid:focus {
    border-color: #cd201f;
    box-shadow: 0 0 0 2px rgba(205, 32, 31, 0.25);
}

.was-validated .custom-select:invalid~.invalid-feedback,
.was-validated .dataTables_wrapper .dataTables_length select:invalid~.invalid-feedback,
.dataTables_wrapper .dataTables_length .was-validated select:invalid~.invalid-feedback,
.was-validated .custom-select:invalid~.invalid-tooltip,
.was-validated .dataTables_wrapper .dataTables_length select:invalid~.invalid-tooltip,
.dataTables_wrapper .dataTables_length .was-validated select:invalid~.invalid-tooltip,
.custom-select.is-invalid~.invalid-feedback,
.dataTables_wrapper .dataTables_length select.is-invalid~.invalid-feedback,
.custom-select.is-invalid~.invalid-tooltip,
.dataTables_wrapper .dataTables_length select.is-invalid~.invalid-tooltip {
    display: block;
}

@media (min-width: 576px) {
    .form-inline .form-control,
    .form-inline .dataTables_wrapper .dataTables_length select,
    .dataTables_wrapper .dataTables_length .form-inline select,
    .form-inline .dataTables_wrapper .dataTables_filter input,
    .dataTables_wrapper .dataTables_filter .form-inline input {
        display: inline-block;
        width: auto;
        vertical-align: middle;
    }
    .form-inline .input-group,
    .form-inline .custom-select,
    .form-inline .dataTables_wrapper .dataTables_length select,
    .dataTables_wrapper .dataTables_length .form-inline select {
        width: auto;
    }
}

@media (prefers-reduced-motion: reduce) {
    .btn,
    .dataTables_wrapper .dataTables_paginate .paginate_button,
    .dataTables_wrapper .dataTables_paginate .paginate_button.current {
        transition: none;
    }
}

.btn:focus,
.dataTables_wrapper .dataTables_paginate .paginate_button:focus,
.btn.focus,
.dataTables_wrapper .dataTables_paginate .focus.paginate_button {
    outline: 0;
    box-shadow: 0 0 0 2px rgba(70, 127, 207, 0.25);
}

.btn.disabled,
.dataTables_wrapper .dataTables_paginate .disabled.paginate_button,
.btn:disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button:disabled {
    opacity: 0.65;
}

a.btn.disabled,
.dataTables_wrapper .dataTables_paginate a.disabled.paginate_button,
fieldset:disabled a.btn,
fieldset:disabled .dataTables_wrapper .dataTables_paginate a.paginate_button,
.dataTables_wrapper .dataTables_paginate fieldset:disabled a.paginate_button {
    pointer-events: none;
}

.btn-primary,
.dataTables_wrapper .dataTables_paginate .paginate_button.current {
    color: #fff;
    background-color: #467fcf;
    border-color: #467fcf;
}

.btn-primary:hover,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:hover {
    color: #fff;
    background-color: #316cbe;
    border-color: #2f66b3;
}

.btn-primary:focus,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:focus,
.btn-primary.focus,
.dataTables_wrapper .dataTables_paginate .focus.paginate_button.current {
    box-shadow: 0 0 0 2px rgba(98, 146, 214, 0.5);
}

.btn-primary.disabled,
.dataTables_wrapper .dataTables_paginate .disabled.paginate_button.current,
.btn-primary:disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:disabled {
    color: #fff;
    background-color: #467fcf;
    border-color: #467fcf;
}

.btn-primary:not(:disabled):not(.disabled):active,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:not(:disabled):not(.disabled):active,
.btn-primary:not(:disabled):not(.disabled).active,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:not(:disabled):not(.disabled).active,
.show>.btn-primary.dropdown-toggle,
.dataTables_wrapper .dataTables_paginate .show>.dropdown-toggle.paginate_button.current {
    color: #fff;
    background-color: #2f66b3;
    border-color: #2c60a9;
}

.btn-primary:not(:disabled):not(.disabled):active:focus,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:not(:disabled):not(.disabled):active:focus,
.btn-primary:not(:disabled):not(.disabled).active:focus,
.dataTables_wrapper .dataTables_paginate .paginate_button.current:not(:disabled):not(.disabled).active:focus,
.show>.btn-primary.dropdown-toggle:focus,
.dataTables_wrapper .dataTables_paginate .show>.dropdown-toggle.paginate_button.current:focus {
    box-shadow: 0 0 0 2px rgba(98, 146, 214, 0.5);
}

.btn-secondary:hover,
.dataTables_wrapper .dataTables_paginate .paginate_button:hover {
    color: #fff;
    background-color: #727b84;
    border-color: #6c757d;
}

.btn-secondary:focus,
.dataTables_wrapper .dataTables_paginate .paginate_button:focus,
.btn-secondary.focus,
.dataTables_wrapper .dataTables_paginate .focus.paginate_button {
    box-shadow: 0 0 0 2px rgba(152, 159, 166, 0.5);
}

.btn-secondary.disabled,
.dataTables_wrapper .dataTables_paginate .disabled.paginate_button,
.btn-secondary:disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button:disabled {
    color: #fff;
    background-color: #868e96;
    border-color: #868e96;
}

.btn-secondary:not(:disabled):not(.disabled):active:focus,
.dataTables_wrapper .dataTables_paginate .paginate_button:not(:disabled):not(.disabled):active:focus,
.btn-secondary:not(:disabled):not(.disabled).active:focus,
.dataTables_wrapper .dataTables_paginate .paginate_button:not(:disabled):not(.disabled).active:focus,
.show>.btn-secondary.dropdown-toggle:focus,
.dataTables_wrapper .dataTables_paginate .show>.dropdown-toggle.paginate_button:focus {
    box-shadow: 0 0 0 2px rgba(152, 159, 166, 0.5);
}

.btn-lg,
.btn-group-lg>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-lg>.paginate_button {
    padding: 0.5rem 1rem;
    font-size: 1.125rem;
    line-height: 1.625;
    border-radius: 3px;
}

.btn-sm,
.btn-group-sm>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-sm>.paginate_button {
    padding: 0.25rem 0.5rem;
    font-size: 0.875rem;
    line-height: 1.33333333;
    border-radius: 3px;
}

.btn-group>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group>.paginate_button,
.btn-group-vertical>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.paginate_button {
    position: relative;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
}

.btn-group>.btn:hover,
.dataTables_wrapper .dataTables_paginate .btn-group>.paginate_button:hover,
.btn-group-vertical>.btn:hover,
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.paginate_button:hover {
    z-index: 1;
}

.btn-group>.btn:focus,
.dataTables_wrapper .dataTables_paginate .btn-group>.paginate_button:focus,
.btn-group>.btn:active,
.dataTables_wrapper .dataTables_paginate .btn-group>.paginate_button:active,
.btn-group>.btn.active,
.dataTables_wrapper .dataTables_paginate .btn-group>.active.paginate_button,
.btn-group-vertical>.btn:focus,
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.paginate_button:focus,
.btn-group-vertical>.btn:active,
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.paginate_button:active,
.btn-group-vertical>.btn.active,
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.active.paginate_button {
    z-index: 1;
}

.btn-group>.btn:not(:first-child),
.dataTables_wrapper .dataTables_paginate .btn-group>.paginate_button:not(:first-child),
.btn-group>.btn-group:not(:first-child) {
    margin-left: -1px;
}

.btn-group>.btn:not(:last-child):not(.dropdown-toggle),
.dataTables_wrapper .dataTables_paginate .btn-group>.paginate_button:not(:last-child):not(.dropdown-toggle),
.btn-group>.btn-group:not(:last-child)>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group>.btn-group:not(:last-child)>.paginate_button {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}

.btn-group>.btn:not(:first-child),
.dataTables_wrapper .dataTables_paginate .btn-group>.paginate_button:not(:first-child),
.btn-group>.btn-group:not(:first-child)>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group>.btn-group:not(:first-child)>.paginate_button {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
}

.btn-sm+.dropdown-toggle-split,
.btn-group-sm>.btn+.dropdown-toggle-split,
.dataTables_wrapper .dataTables_paginate .btn-group-sm>.paginate_button+.dropdown-toggle-split {
    padding-right: 0.375rem;
    padding-left: 0.375rem;
}

.btn-lg+.dropdown-toggle-split,
.btn-group-lg>.btn+.dropdown-toggle-split,
.dataTables_wrapper .dataTables_paginate .btn-group-lg>.paginate_button+.dropdown-toggle-split {
    padding-right: 0.75rem;
    padding-left: 0.75rem;
}

.btn-group-vertical>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.paginate_button,
.btn-group-vertical>.btn-group {
    width: 100%;
}

.btn-group-vertical>.btn:not(:first-child),
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.paginate_button:not(:first-child),
.btn-group-vertical>.btn-group:not(:first-child) {
    margin-top: -1px;
}

.btn-group-vertical>.btn:not(:last-child):not(.dropdown-toggle),
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.paginate_button:not(:last-child):not(.dropdown-toggle),
.btn-group-vertical>.btn-group:not(:last-child)>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.btn-group:not(:last-child)>.paginate_button {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}

.btn-group-vertical>.btn:not(:first-child),
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.paginate_button:not(:first-child),
.btn-group-vertical>.btn-group:not(:first-child)>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-vertical>.btn-group:not(:first-child)>.paginate_button {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.btn-group-toggle>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-toggle>.paginate_button,
.btn-group-toggle>.btn-group>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-toggle>.btn-group>.paginate_button {
    margin-bottom: 0;
}

.btn-group-toggle>.btn input[type="radio"],
.dataTables_wrapper .dataTables_paginate .btn-group-toggle>.paginate_button input[type="radio"],
.btn-group-toggle>.btn input[type="checkbox"],
.dataTables_wrapper .dataTables_paginate .btn-group-toggle>.paginate_button input[type="checkbox"],
.btn-group-toggle>.btn-group>.btn input[type="radio"],
.dataTables_wrapper .dataTables_paginate .btn-group-toggle>.btn-group>.paginate_button input[type="radio"],
.btn-group-toggle>.btn-group>.btn input[type="checkbox"],
.dataTables_wrapper .dataTables_paginate .btn-group-toggle>.btn-group>.paginate_button input[type="checkbox"] {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    pointer-events: none;
}

.input-group>.form-control,
.dataTables_wrapper .dataTables_length .input-group>select,
.dataTables_wrapper .dataTables_filter .input-group>input,
.input-group>.form-control-plaintext,
.input-group>.custom-select,
.dataTables_wrapper .dataTables_length .input-group>select,
.input-group>.custom-file {
    position: relative;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
    width: 1%;
    margin-bottom: 0;
}

.input-group>.form-control+.form-control,
.dataTables_wrapper .dataTables_length .input-group>select+.form-control,
.dataTables_wrapper .dataTables_filter .input-group>input+.form-control,
.dataTables_wrapper .dataTables_length .input-group>.form-control+select,
.dataTables_wrapper .dataTables_length .input-group>select+select,
.dataTables_wrapper .dataTables_filter .dataTables_length .input-group>input+select,
.dataTables_wrapper .dataTables_length .dataTables_filter .input-group>input+select,
.dataTables_wrapper .dataTables_filter .input-group>.form-control+input,
.dataTables_wrapper .dataTables_length .dataTables_filter .input-group>select+input,
.dataTables_wrapper .dataTables_filter .dataTables_length .input-group>select+input,
.dataTables_wrapper .dataTables_filter .input-group>input+input,
.input-group>.form-control+.custom-select,
.dataTables_wrapper .dataTables_length .input-group>select+.custom-select,
.dataTables_wrapper .dataTables_filter .input-group>input+.custom-select,
.dataTables_wrapper .dataTables_length .input-group>.form-control+select,
.dataTables_wrapper .dataTables_length .input-group>select+select,
.dataTables_wrapper .dataTables_filter .dataTables_length .input-group>input+select,
.dataTables_wrapper .dataTables_length .dataTables_filter .input-group>input+select,
.input-group>.form-control+.custom-file,
.dataTables_wrapper .dataTables_length .input-group>select+.custom-file,
.dataTables_wrapper .dataTables_filter .input-group>input+.custom-file,
.input-group>.form-control-plaintext+.form-control,
.dataTables_wrapper .dataTables_length .input-group>.form-control-plaintext+select,
.dataTables_wrapper .dataTables_filter .input-group>.form-control-plaintext+input,
.input-group>.form-control-plaintext+.custom-select,
.dataTables_wrapper .dataTables_length .input-group>.form-control-plaintext+select,
.input-group>.form-control-plaintext+.custom-file,
.input-group>.custom-select+.form-control,
.dataTables_wrapper .dataTables_length .input-group>select+.form-control,
.dataTables_wrapper .dataTables_length .input-group>.custom-select+select,
.dataTables_wrapper .dataTables_length .input-group>select+select,
.dataTables_wrapper .dataTables_filter .input-group>.custom-select+input,
.dataTables_wrapper .dataTables_length .dataTables_filter .input-group>select+input,
.dataTables_wrapper .dataTables_filter .dataTables_length .input-group>select+input,
.input-group>.custom-select+.custom-select,
.dataTables_wrapper .dataTables_length .input-group>select+.custom-select,
.dataTables_wrapper .dataTables_length .input-group>.custom-select+select,
.dataTables_wrapper .dataTables_length .input-group>select+select,
.input-group>.custom-select+.custom-file,
.dataTables_wrapper .dataTables_length .input-group>select+.custom-file,
.input-group>.custom-file+.form-control,
.dataTables_wrapper .dataTables_length .input-group>.custom-file+select,
.dataTables_wrapper .dataTables_filter .input-group>.custom-file+input,
.input-group>.custom-file+.custom-select,
.dataTables_wrapper .dataTables_length .input-group>.custom-file+select,
.input-group>.custom-file+.custom-file {
    margin-left: -1px;
}

.input-group>.form-control:focus,
.dataTables_wrapper .dataTables_length .input-group>select:focus,
.dataTables_wrapper .dataTables_filter .input-group>input:focus,
.input-group>.custom-select:focus,
.dataTables_wrapper .dataTables_length .input-group>select:focus,
.input-group>.custom-file .custom-file-input:focus~.custom-file-label {
    z-index: 3;
}

.input-group>.custom-file .custom-file-input:focus {
    z-index: 4;
}

.input-group>.form-control:not(:last-child),
.dataTables_wrapper .dataTables_length .input-group>select:not(:last-child),
.dataTables_wrapper .dataTables_filter .input-group>input:not(:last-child),
.input-group>.custom-select:not(:last-child),
.dataTables_wrapper .dataTables_length .input-group>select:not(:last-child) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}

.input-group>.form-control:not(:first-child),
.dataTables_wrapper .dataTables_length .input-group>select:not(:first-child),
.dataTables_wrapper .dataTables_filter .input-group>input:not(:first-child),
.input-group>.custom-select:not(:first-child),
.dataTables_wrapper .dataTables_length .input-group>select:not(:first-child) {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
}

.input-group-prepend .btn,
.input-group-prepend .dataTables_wrapper .dataTables_paginate .paginate_button,
.dataTables_wrapper .dataTables_paginate .input-group-prepend .paginate_button,
.input-group-append .btn,
.input-group-append .dataTables_wrapper .dataTables_paginate .paginate_button,
.dataTables_wrapper .dataTables_paginate .input-group-append .paginate_button {
    position: relative;
    z-index: 2;
}

.input-group-prepend .btn:focus,
.input-group-prepend .dataTables_wrapper .dataTables_paginate .paginate_button:focus,
.dataTables_wrapper .dataTables_paginate .input-group-prepend .paginate_button:focus,
.input-group-append .btn:focus,
.input-group-append .dataTables_wrapper .dataTables_paginate .paginate_button:focus,
.dataTables_wrapper .dataTables_paginate .input-group-append .paginate_button:focus {
    z-index: 3;
}

.input-group-prepend .btn+.btn,
.input-group-prepend .dataTables_wrapper .dataTables_paginate .paginate_button+.btn,
.dataTables_wrapper .dataTables_paginate .input-group-prepend .paginate_button+.btn,
.input-group-prepend .dataTables_wrapper .dataTables_paginate .btn+.paginate_button,
.dataTables_wrapper .dataTables_paginate .input-group-prepend .btn+.paginate_button,
.input-group-prepend .dataTables_wrapper .dataTables_paginate .paginate_button+.paginate_button,
.dataTables_wrapper .dataTables_paginate .input-group-prepend .paginate_button+.paginate_button,
.input-group-prepend .btn+.input-group-text,
.input-group-prepend .dataTables_wrapper .dataTables_paginate .paginate_button+.input-group-text,
.dataTables_wrapper .dataTables_paginate .input-group-prepend .paginate_button+.input-group-text,
.input-group-prepend .input-group-text+.input-group-text,
.input-group-prepend .input-group-text+.btn,
.input-group-prepend .dataTables_wrapper .dataTables_paginate .input-group-text+.paginate_button,
.dataTables_wrapper .dataTables_paginate .input-group-prepend .input-group-text+.paginate_button,
.input-group-append .btn+.btn,
.input-group-append .dataTables_wrapper .dataTables_paginate .paginate_button+.btn,
.dataTables_wrapper .dataTables_paginate .input-group-append .paginate_button+.btn,
.input-group-append .dataTables_wrapper .dataTables_paginate .btn+.paginate_button,
.dataTables_wrapper .dataTables_paginate .input-group-append .btn+.paginate_button,
.input-group-append .dataTables_wrapper .dataTables_paginate .paginate_button+.paginate_button,
.dataTables_wrapper .dataTables_paginate .input-group-append .paginate_button+.paginate_button,
.input-group-append .btn+.input-group-text,
.input-group-append .dataTables_wrapper .dataTables_paginate .paginate_button+.input-group-text,
.dataTables_wrapper .dataTables_paginate .input-group-append .paginate_button+.input-group-text,
.input-group-append .input-group-text+.input-group-text,
.input-group-append .input-group-text+.btn,
.input-group-append .dataTables_wrapper .dataTables_paginate .input-group-text+.paginate_button,
.dataTables_wrapper .dataTables_paginate .input-group-append .input-group-text+.paginate_button {
    margin-left: -1px;
}

.input-group-lg>.form-control:not(textarea),
.dataTables_wrapper .dataTables_length .input-group-lg>select:not(textarea),
.dataTables_wrapper .dataTables_filter .input-group-lg>input:not(textarea),
.input-group-lg>.custom-select,
.dataTables_wrapper .dataTables_length .input-group-lg>select {
    height: calc(1.44444444em + 1rem + 2px);
}

.input-group-lg>.form-control,
.dataTables_wrapper .dataTables_length .input-group-lg>select,
.dataTables_wrapper .dataTables_filter .input-group-lg>input,
.input-group-lg>.custom-select,
.dataTables_wrapper .dataTables_length .input-group-lg>select,
.input-group-lg>.input-group-prepend>.input-group-text,
.input-group-lg>.input-group-append>.input-group-text,
.input-group-lg>.input-group-prepend>.btn,
.dataTables_wrapper .dataTables_paginate .input-group-lg>.input-group-prepend>.paginate_button,
.input-group-lg>.input-group-append>.btn,
.dataTables_wrapper .dataTables_paginate .input-group-lg>.input-group-append>.paginate_button {
    padding: 0.5rem 1rem;
    font-size: 1.125rem;
    line-height: 1.44444444;
    border-radius: 3px;
}

.input-group-sm>.form-control:not(textarea),
.dataTables_wrapper .dataTables_length .input-group-sm>select:not(textarea),
.dataTables_wrapper .dataTables_filter .input-group-sm>input:not(textarea),
.input-group-sm>.custom-select,
.dataTables_wrapper .dataTables_length .input-group-sm>select {
    height: calc(1.14285714em + 0.5rem + 2px);
}

.input-group-sm>.form-control,
.dataTables_wrapper .dataTables_length .input-group-sm>select,
.dataTables_wrapper .dataTables_filter .input-group-sm>input,
.input-group-sm>.custom-select,
.dataTables_wrapper .dataTables_length .input-group-sm>select,
.input-group-sm>.input-group-prepend>.input-group-text,
.input-group-sm>.input-group-append>.input-group-text,
.input-group-sm>.input-group-prepend>.btn,
.dataTables_wrapper .dataTables_paginate .input-group-sm>.input-group-prepend>.paginate_button,
.input-group-sm>.input-group-append>.btn,
.dataTables_wrapper .dataTables_paginate .input-group-sm>.input-group-append>.paginate_button {
    padding: 0.25rem 0.5rem;
    font-size: 0.875rem;
    line-height: 1.14285714;
    border-radius: 3px;
}

.input-group-lg>.custom-select,
.dataTables_wrapper .dataTables_length .input-group-lg>select,
.input-group-sm>.custom-select,
.dataTables_wrapper .dataTables_length .input-group-sm>select {
    padding-right: 1.75rem;
}

.input-group>.input-group-prepend>.btn,
.dataTables_wrapper .dataTables_paginate .input-group>.input-group-prepend>.paginate_button,
.input-group>.input-group-prepend>.input-group-text,
.input-group>.input-group-append:not(:last-child)>.btn,
.dataTables_wrapper .dataTables_paginate .input-group>.input-group-append:not(:last-child)>.paginate_button,
.input-group>.input-group-append:not(:last-child)>.input-group-text,
.input-group>.input-group-append:last-child>.btn:not(:last-child):not(.dropdown-toggle),
.dataTables_wrapper .dataTables_paginate .input-group>.input-group-append:last-child>.paginate_button:not(:last-child):not(.dropdown-toggle),
.input-group>.input-group-append:last-child>.input-group-text:not(:last-child) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}

.input-group>.input-group-append>.btn,
.dataTables_wrapper .dataTables_paginate .input-group>.input-group-append>.paginate_button,
.input-group>.input-group-append>.input-group-text,
.input-group>.input-group-prepend:not(:first-child)>.btn,
.dataTables_wrapper .dataTables_paginate .input-group>.input-group-prepend:not(:first-child)>.paginate_button,
.input-group>.input-group-prepend:not(:first-child)>.input-group-text,
.input-group>.input-group-prepend:first-child>.btn:not(:first-child),
.dataTables_wrapper .dataTables_paginate .input-group>.input-group-prepend:first-child>.paginate_button:not(:first-child),
.input-group>.input-group-prepend:first-child>.input-group-text:not(:first-child) {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
}

.custom-select,
.dataTables_wrapper .dataTables_length select {
    display: inline-block;
    width: 100%;
    height: 2.375rem;
    padding: 0.5rem 1.75rem 0.5rem 0.75rem;
    font-size: 0.9375rem;
    font-weight: 400;
    line-height: 1.6;
    color: #495057;
    vertical-align: middle;
    background: url("data:image/svg+xml;charset=utf8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 10 5'%3E%3Cpath fill='#999' d='M0 0L10 0L5 5L0 0'/%3E%3C/svg%3E") no-repeat right 0.75rem center/8px 10px;
    background-color: #fff;
    border: 1px solid rgba(0, 40, 100, 0.12);
    border-radius: 3px;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
}

.custom-select:focus,
.dataTables_wrapper .dataTables_length select:focus {
    border-color: #1991eb;
    outline: 0;
    box-shadow: 0 0 0 2px rgba(70, 127, 207, 0.25);
}

.custom-select:focus::-ms-value,
.dataTables_wrapper .dataTables_length select:focus::-ms-value {
    color: #495057;
    background-color: #fff;
}

.custom-select[multiple],
.dataTables_wrapper .dataTables_length select[multiple],
.custom-select[size]:not([size="1"]),
.dataTables_wrapper .dataTables_length select[size]:not([size="1"]) {
    height: auto;
    padding-right: 0.75rem;
    background-image: none;
}

.custom-select:disabled,
.dataTables_wrapper .dataTables_length select:disabled {
    color: #868e96;
    background-color: #e9ecef;
}

.custom-select::-ms-expand,
.dataTables_wrapper .dataTables_length select::-ms-expand {
    display: none;
}

.custom-control-label::before,
.custom-file-label,
.custom-select,
.dataTables_wrapper .dataTables_length select {
    transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
}

@media (prefers-reduced-motion: reduce) {
    .custom-control-label::before,
    .custom-file-label,
    .custom-select,
    .dataTables_wrapper .dataTables_length select {
        transition: none;
    }
}

.btn .badge,
.dataTables_wrapper .dataTables_paginate .paginate_button .badge {
    position: relative;
    top: -1px;
}

.btn i,
.dataTables_wrapper .dataTables_paginate .paginate_button i,
.dataTables_wrapper .dataTables_paginate .paginate_button.current i {
    font-size: 1rem;
    vertical-align: -2px;
}

.btn-secondary:hover,
.dataTables_wrapper .dataTables_paginate .paginate_button:hover {
    color: #495057;
    background-color: #f6f6f6;
    border-color: rgba(0, 20, 49, 0.12);
}

.btn-secondary:focus,
.dataTables_wrapper .dataTables_paginate .paginate_button:focus,
.btn-secondary.focus,
.dataTables_wrapper .dataTables_paginate .focus.paginate_button {
    box-shadow: 0 0 0 2px rgba(54, 69, 90, 0.5);
}

.btn-secondary.disabled,
.dataTables_wrapper .dataTables_paginate .disabled.paginate_button,
.btn-secondary:disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button:disabled {
    color: #495057;
    background-color: #fff;
    border-color: rgba(0, 40, 100, 0.12);
}

.btn-sm,
.btn-group-sm>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-sm>.paginate_button {
    font-size: 0.75rem;
    min-width: 1.625rem;
}

.btn-lg,
.btn-group-lg>.btn,
.dataTables_wrapper .dataTables_paginate .btn-group-lg>.paginate_button {
    font-size: 1rem;
    min-width: 2.75rem;
    font-weight: 400;
}

.btn-list>.btn,
.dataTables_wrapper .dataTables_paginate .btn-list>.paginate_button,
.btn-list>.dropdown {
    margin-bottom: .5rem;
}

.btn-list>.btn:not(:last-child),
.dataTables_wrapper .dataTables_paginate .btn-list>.paginate_button:not(:last-child),
.btn-list>.dropdown:not(:last-child) {
    margin-right: .5rem;
}

.btn-loading.btn-sm:after,
.btn-group-sm>.btn-loading.btn:after,
.dataTables_wrapper .dataTables_paginate .btn-group-sm>.btn-loading.paginate_button:after {
    height: 1em;
    width: 1em;
    left: calc(50% - (1em / 2));
    top: calc(50% - (1em / 2));
}

.btn-loading.btn-secondary:after,
.dataTables_wrapper .dataTables_paginate .btn-loading.paginate_button:after {
    border-color: #495057;
}

.input-group-prepend>.btn,
.dataTables_wrapper .dataTables_paginate .input-group-prepend>.paginate_button,
.input-group-append>.btn,
.dataTables_wrapper .dataTables_paginate .input-group-append>.paginate_button,
.input-group-btn>.btn,
.dataTables_wrapper .dataTables_paginate .input-group-btn>.paginate_button {
    height: 100%;
    border-color: rgba(0, 40, 100, 0.12);
}

.input-icon .form-control:not(:last-child),
.input-icon .dataTables_wrapper .dataTables_length select:not(:last-child),
.dataTables_wrapper .dataTables_length .input-icon select:not(:last-child),
.input-icon .dataTables_wrapper .dataTables_filter input:not(:last-child),
.dataTables_wrapper .dataTables_filter .input-icon input:not(:last-child) {
    padding-right: 2.5rem;
}

.input-icon .form-control:not(:first-child),
.input-icon .dataTables_wrapper .dataTables_length select:not(:first-child),
.dataTables_wrapper .dataTables_length .input-icon select:not(:first-child),
.input-icon .dataTables_wrapper .dataTables_filter input:not(:first-child),
.dataTables_wrapper .dataTables_filter .input-icon input:not(:first-child) {
    padding-left: 2.5rem;
}

.dataTables_wrapper thead .sorting {
    position: relative;
}

.dataTables_wrapper thead .sorting:after {
    position: absolute;
    right: 0;
    bottom: 5px;
    content: "\e92d";
    font-family: 'feather' !important;
}

.dataTables_wrapper thead .sorting:before {
    position: absolute;
    right: 0;
    top: 5px;
    content: "\e930";
    font-family: 'feather' !important;
}

.dataTables_wrapper thead .sorting_desc {
    position: relative;
}

.dataTables_wrapper thead .sorting_desc:after {
    position: absolute;
    right: 0;
    bottom: 5px;
    content: "\e92d";
    font-family: 'feather' !important;
}

.dataTables_wrapper thead .sorting_asc {
    position: relative;
}

.dataTables_wrapper thead .sorting_asc:after {
    position: absolute;
    right: 0;
    top: 5px;
    content: "\e930";
    font-family: 'feather' !important;
}

.dataTables_wrapper .table,
.dataTables_wrapper .text-wrap table,
.text-wrap .dataTables_wrapper table {
    border-top: 1px solid rgba(0, 40, 100, 0.12);
    border-bottom: 1px solid rgba(0, 40, 100, 0.12);
}

.dataTables_wrapper .dataTables_length {
    margin: 1rem 1.5rem;
    float: left;
}

.dataTables_wrapper .dataTables_length select {
    width: auto;
    display: inline-block;
    margin: 0 0.2rem;
}

.dataTables_wrapper .dataTables_filter {
    float: right;
    margin: 1rem 1.5rem;
    text-align: right;
    color: #495057;
}

.dataTables_wrapper .dataTables_filter input {
    width: auto;
    margin-left: 0.2rem;
    display: inline-block;
}

.dataTables_wrapper .dataTables_paginate {
    float: right !important;
    text-align: right !important;
    margin: 1rem 1.5rem !important;
}

.dataTables_wrapper .dataTables_paginate .paginate_button {
    margin: 0 0.2rem;
}

.dataTables_wrapper .dataTables_info {
    clear: both;
    float: left;
    margin: 1rem 1.5rem;
    color: #495057;
    line-height: 38px;
}