<!doctype html>
<html lang="en">

<head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1, viewport-fit=cover" />
    <meta http-equiv="X-UA-Compatible" content="ie=edge" />
    <title>Velero Dashboard - {% block title %}{% endblock %}</title>
    <link rel="preconnect" href="https://fonts.gstatic.com/" crossorigin>
    <meta name="msapplication-TileColor" content="#206bc4" />
    <meta name="theme-color" content="#206bc4" />
    <meta name="apple-mobile-web-app-status-bar-style" content="black-translucent" />
    <meta name="apple-mobile-web-app-capable" content="yes" />
    <meta name="mobile-web-app-capable" content="yes" />
    <meta name="HandheldFriendly" content="True" />
    <meta name="MobileOptimized" content="320" />
    <meta name="robots" content="noindex,nofollow,noarchive" />
    <link rel="icon" href="./favicon.ico" type="image/x-icon" />
    <link rel="shortcut icon" href="./favicon.ico" type="image/x-icon" />
    <!-- Libs CSS
    <link href="./dist/libs/jqvmap/dist/jqvmap.min.css" rel="stylesheet" />
    <link href="./dist/libs/selectize/dist/css/selectize.css" rel="stylesheet" />
    <link href="./dist/libs/fullcalendar/core/main.min.css" rel="stylesheet" />
    <link href="./dist/libs/fullcalendar/daygrid/main.min.css" rel="stylesheet" />
    <link href="./dist/libs/fullcalendar/timegrid/main.min.css" rel="stylesheet" />
    <link href="./dist/libs/fullcalendar/list/main.min.css" rel="stylesheet" />
    <link href="./dist/libs/flatpickr/dist/flatpickr.min.css" rel="stylesheet" />
    <link href="./dist/libs/nouislider/distribute/nouislider.min.css" rel="stylesheet" />
    <link href="https://api.mapbox.com/mapbox-gl-js/v1.8.0/mapbox-gl.css" rel="stylesheet" /-->
    <!-- Tabler Core -->
    <link href="{{ url_for('static', filename='css/tabler/tabler.min.css') }}" rel="stylesheet" />
    <!-- Tabler Plugins -->
    <link href="{{ url_for('static', filename='css/tabler/tabler-flags.min.css') }}" rel="stylesheet" />
    <link href="{{ url_for('static', filename='css/tabler/tabler-payments.min.css') }}" rel="stylesheet" />
    <link href="{{ url_for('static', filename='css/tabler/tabler-buttons.min.css') }}" rel="stylesheet" />
    <link rel="stylesheet" href="{{ url_for('static', filename='css/toastr/toastr.min.css') }}" crossorigin="anonymous" />
    <style>
        body {
            display: none;
        }
    </style> {%- block css %}{% endblock -%}
</head>

<body class="antialiased">
    <aside class="navbar navbar-vertical navbar-expand-lg navbar-dark">
        <div class="container">
            <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbar-menu">
                    <span class="navbar-toggler-icon"></span>
                </button>
            <a href="." class="navbar-brand navbar-brand-autodark">
                <img src="{{ url_for('static', filename='img/velero_logo_white.svg') }}" style="height: 3em" alt="Velero" class="navbar-brand-image">
            </a>
            <div class="collapse navbar-collapse" id="navbar-menu"> {% include "shared/menu.html" %} </div>
        </div>
    </aside>
    <div class="page">
        <div class="content">
            <div class="container-fluid"> {% block body %}{% endblock %} </div>
            <footer class="footer footer-transparent">
                <div class="container">
                    <div class="row text-center align-items-center flex-row-reverse">
                        <div class="col-lg-auto ml-lg-auto">
                            <ul class="list-inline list-inline-dots mb-0">
                                <li class="list-inline-item"><a href="./docs/index.html" class="link-secondary">Documentation</a></li>
                                <li class="list-inline-item"><a href="https://github.com/tabler/tabler" target="_blank" class="link-secondary">Source code</a></li>
                            </ul>
                        </div>
                        <div class="col-12 col-lg-auto mt-3 mt-lg-0"> Copyright © 2020 <a href="." class="link-secondary">Velero Admin</a>. All rights reserved. </div>
                    </div>
                </div>
            </footer>
        </div>
    </div>
    <!-- Libs JS -->
    <script src="{{ url_for('static', filename='js/jquery/jquery-3.5.1.min.js') }}"></script>
    <script src="{{ url_for('static', filename='libs/bootstrap/dist/js/bootstrap.bundle.min.js') }}"></script>
    <script src="{{ url_for('static', filename='libs/apexcharts/dist/apexcharts.min.js') }}"></script>
    <script src="{{ url_for('static', filename='libs/jqvmap/dist/jquery.vmap.min.js') }}"></script>
    <script src="{{ url_for('static', filename='libs/jqvmap/dist/maps/jquery.vmap.world.js') }}"></script>
    <script src="{{ url_for('static', filename='libs/jqvmap/dist/maps/jquery.vmap.usa.js') }}"></script>
    <script src="{{ url_for('static', filename='libs/jqvmap/dist/maps/continents/jquery.vmap.europe.js') }}"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js" integrity="sha256-/xUj+3OJU5yExlq6GSYGSHk7tPXikynS7ogEvDej/m4=" crossorigin="anonymous"></script>
    <script src="{{ url_for('static', filename='js/toastr/toastr.min.js') }}"></script>
    <script src="{{ url_for('static', filename='js/feather/feather.min.js') }}"></script>
    <!-- Tabler Core -->
    <script src="https://unpkg.com/@tabler/core@latest/dist/js/tabler.min.js"></script>
    {%- block javascript %}{% endblock -%} {% with messages = get_flashed_messages(with_categories=true) %} {% if messages %} {% for category, message in messages %}
    <script type="text/javascript">
        toastr.options = {
            closeButton: true,
            debug: false,
            newestOnTop: true,
            progressBar: true,
            positionClass: "toast-top-right",
            preventDuplicates: true,
            onclick: null,
            showDuration: "300",
            hideDuration: "1000",
            timeOut: "5000",
            extendedTimeOut: "1000",
            showEasing: "swing",
            hideEasing: "linear",
            showMethod: "fadeIn",
            hideMethod: "fadeOut",
        };
        toastr["{{ category }}"]("{{ message }}", "{{ category[0]|upper}}{{category[1:] }}");
    </script>
    {% endfor %} {% endif %} {% endwith %}
    <script>
        document.body.style.display = "block"
    </script>
</body>

</html>