<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no" />
    <meta name="description" content="" />
    <meta name="author" content="Kleber Rocha" />
    <meta name="msapplication-config" content="/docs/4.5/assets/img/favicons/browserconfig.xml" />
    <title>Velero Dashboard</title>
</head>

<body class="bg-color-404">
    <div class="box-404">
        <h1 class="h1-404">Oppsss</h1>
        <img src="{{ url_for('static', filename='img/forbiden.svg') }}" />
    </div>
</body>

</html>